import { Lock } from "@hibas123/utils";
import { LoggingBase } from "@hibas123/logging";
export declare class HttpError extends Error {
    status: number;
    statusText: string;
    constructor(status: number, statusText: string);
}
export interface Position {
    date: Date;
    chapter: string;
    progress: number;
}
export interface VerySmallWork {
    _id: string;
    position: Position;
    creation_date: Date;
}
export interface BaseWork extends VerySmallWork {
    type: string;
    workid: string;
    title: string;
    summary: string;
    tags: string[];
    author: string;
    cover: string;
    new: boolean;
    folder: string;
    words: number;
    progress: number;
}
export interface BaseChapter {
    id: string;
    title: string;
    words: number;
}
export interface FullChapter extends BaseChapter {
    content: string;
}
export interface FullWork extends BaseWork {
    chapters: FullChapter[];
}
export interface SmallWork extends BaseWork {
    chapters: BaseChapter[];
}
export declare enum WorkChangeTypes {
    create_edit = 0,
    delete = 1,
    position = 2
}
export interface IManuallyChapter {
    id: string;
    title: string;
    content: string;
}
export interface IManuallyEbook {
    workid: string;
    type: "manually";
    title: string;
    summary: string;
    tags: string[];
    author: string;
    cover: string;
    chapters: IManuallyChapter[];
}
export default class EbookServerApi {
    private auth_server;
    private client_id;
    private version;
    readonly logging: LoggingBase;
    readonly finishedLimit = 0.98;
    private syncLock;
    private refreshToken;
    private jwt;
    private storage;
    private workObersvableServer;
    workObservable: import("@hibas123/utils").ObservableInterface<{
        type: WorkChangeTypes;
        work: SmallWork;
    }>;
    private loginObeservableServer;
    loginObservable: import("@hibas123/utils").ObservableInterface<{
        need_login: boolean;
    }>;
    private _needLogin;
    get needLogin(): boolean;
    set needLogin(val: boolean);
    authLock: Lock;
    get loginUrl(): string;
    constructor(auth_server: string, client_id: string, version: number);
    private getJWT;
    private init;
    getToken(code: string): Promise<void>;
    logout(): Promise<void>;
    waitTillInitialized(): Promise<void>;
    makeRequest<T = any>(url: string, method?: "POST" | "GET" | "PUT" | "DELETE", body?: any, contenttype?: string, noauth?: boolean, failjwt?: boolean): Promise<T>;
    getVersion(): Promise<any>;
    getJsonWebToken(): Promise<string>;
    private fixCoverUrl;
    private getVerySmallWorksRemote;
    private getWorksRemote;
    getWorks(): Promise<SmallWork[]>;
    private getWorkRemote;
    getWork(id: string): Promise<FullWork>;
    resolveUrl(url: string): Promise<{
        url: string;
        type: string;
        id: string;
    }>;
    addWorkFromUrl(input: string): Promise<void>;
    addEPub(file: Blob): Promise<void>;
    addAO3(workid: string): Promise<void>;
    addWattpad(workid: string, pos?: string): Promise<void>;
    addWorkWithId(type: string, id: string, pos?: string): Promise<void>;
    addManualWork(work: IManuallyEbook): Promise<void>;
    deleteWork(id: string): Promise<void>;
    private pushPositionRemote;
    private pushPositionLocal;
    pushPosition(id: string, position: Position): Promise<any>;
    sync(): Promise<void>;
}
